@@ -28,17 +28,18 @@
 
 #include "kpEffectCommandBase.h"
 
-#include <klocale.h>
-
 #include "kpDefs.h"
 #include "document/kpDocument.h"
 #include "generic/kpSetOverrideCursorSaver.h"
 
+#include <KLocalizedString>
+
+//--------------------------------------------------------------------------------
 
 struct kpEffectCommandBasePrivate
 {
     QString name;
-    bool actOnSelection;
+    bool actOnSelection{false};
 
     kpImage oldImage;
 };
@@ -62,10 +63,7 @@ kpEffectCommandBase::~kpEffectCommandBase ()
 // public virtual [base kpCommand]
 QString kpEffectCommandBase::name () const
 {
-    if (d->actOnSelection)
-        return i18n ("Selection: %1", d->name);
-    else
-        return d->name;
+    return (d->actOnSelection) ? i18n ("Selection: %1", d->name) : d->name;
 }
 
 
