@@ -76,12 +76,12 @@ kpCommandHistoryBase::kpCommandHistoryBase (bool doReadConfig,
                                             KActionCollection *ac)
     : d (new kpCommandHistoryBasePrivate ())
 {
-    m_actionUndo = new KToolBarPopupAction(KDE::icon("edit-undo"), undoActionText (), this);
+    m_actionUndo = new KToolBarPopupAction(KDE::icon(QStringLiteral("edit-undo")), undoActionText (), this);
     ac->addAction (KStandardAction::name (KStandardAction::Undo), m_actionUndo);
     ac->setDefaultShortcuts (m_actionUndo, KStandardShortcut::shortcut (KStandardShortcut::Undo));
     connect (m_actionUndo, &KToolBarPopupAction::triggered, this, &kpCommandHistoryBase::undo);
 
-    m_actionRedo = new KToolBarPopupAction(KDE::icon("edit-redo"), redoActionText (), this);
+    m_actionRedo = new KToolBarPopupAction(KDE::icon(QStringLiteral("edit-redo")), redoActionText (), this);
     ac->addAction (KStandardAction::name (KStandardAction::Redo), m_actionRedo);
     ac->setDefaultShortcuts (m_actionRedo, KStandardShortcut::shortcut (KStandardShortcut::Redo));
     connect (m_actionRedo, &KToolBarPopupAction::triggered, this, &kpCommandHistoryBase::redo );
