@@ -42,8 +42,8 @@ public:
     kpToolBrush (kpToolEnvironment *environ, QObject *parent);
 
 protected:
-    virtual QString haventBegunDrawUserMessage () const;
-    virtual bool haveDiverseBrushes () const { return true; }
+    QString haventBegunDrawUserMessage () const override;
+    bool haveDiverseBrushes () const override { return true; }
 };
 
 
